@@ -3,7 +3,7 @@ ST = function(sp, time) {
 		sp = as(sp, "SpatialPixels")
 		warning("converted SpatialGrid to SpatialPixels")
 	}
-	new("ST", sp = sp, time = time)
+	new("ST", sp = geometry(sp), time = time)
 }
 
 setMethod("[[", c("ST", "ANY", "missing"), 
@@ -71,23 +71,6 @@ setReplaceMethod("proj4string", signature(obj = "ST", value = "character"),
 	}
 )
 
-asSpatialDataFrame = function(x) { # convert to lower
-	stopifnot(length(x@sp) == nrow(x@data))
-	if (is(x@sp, "SpatialPoints"))
-		return(SpatialPointsDataFrame(x@sp, x@data))
-	if (is(x@sp, "SpatialLines"))
-		return(SpatialLinesDataFrame(x@sp, x@data))
-	if (is(x@sp, "SpatialPixels"))
-		return(SpatialPixelsDataFrame(x@sp, x@data))
-	if (is(x@sp, "SpatialGrid"))
-		return(SpatialGridDataFrame(x@sp, x@data))
-	if (is(x@sp, "SpatialPolygons"))
-		return(SpatialPolygonsDataFrame(x@sp, x@data))
-	#if (is(x@sp, "SpatialRings"))
-	#	return(SpatialRingsDataFrame(x@sp, x@data))
-	stop("unknown Spatial class")
-}
-
 spTransform.ST = function(x, CRSobj, ...) {
 	x@sp = spTransform(x@sp, CRSobj)
 	x
@@ -126,3 +109,20 @@ print.summary.ST = function(x, ...) {
     }
     invisible(x)
 }
+
+#asSpatialDataFrame = function(x) { # convert to lower
+#	stopifnot(length(x@sp) == nrow(x@data))
+#	if (is(x@sp, "SpatialPoints"))
+#		return(SpatialPointsDataFrame(x@sp, x@data))
+#	if (is(x@sp, "SpatialLines"))
+#		return(SpatialLinesDataFrame(x@sp, x@data))
+#	if (is(x@sp, "SpatialPixels"))
+#		return(SpatialPixelsDataFrame(x@sp, x@data))
+#	if (is(x@sp, "SpatialGrid"))
+#		return(SpatialGridDataFrame(x@sp, x@data))
+#	if (is(x@sp, "SpatialPolygons"))
+#		return(SpatialPolygonsDataFrame(x@sp, x@data))
+#	#if (is(x@sp, "SpatialRings"))
+#	#	return(SpatialRingsDataFrame(x@sp, x@data))
+#	stop("unknown Spatial class")
+#}
