@@ -38,29 +38,45 @@ as.data.frame.STSDF = function(x, row.names = NULL, ...) {
 }
 setAs("STSDF", "data.frame", function(from) as.data.frame.STSDF(from))
 
+as.xts.STSDF = function(x, ...) xts(x@data, index(x@sp))
+
 subs.STSDF <- function(x, i, j, ... , drop = FALSE) {
 	missing.i = missing(i)
 	missing.j = missing(j)
+	missing.k = k = TRUE
+	dots = list(...)
+    if (length(dots) > 0) {
+        missing.k = FALSE
+        k = dots[[1]]
+    }
 
-	if (missing.i && missing.j)
+	if (missing.i && missing.j && missing.k)
 		return(x)
 
-	if (missing.j)
-		j = TRUE
-
 	if (missing.i)
 		i = TRUE
-	
-	if (is.character(i)) { # defer to [.xts:
-		t = xts(1:nrow(x@time), index(x@time))[i]
-		i = as.vector(t[,1])
+	else if (is(i, "Spatial"))
+		i = !is.na(over(x@sp,i))
+
+	if (missing.j)
+		j = rep(TRUE, length=nrow(x@time))
+	else {
+		t = xts(1:nrow(x@time), index(x@time))[j]
+		j = as.vector(t[,1])
 	}
+	
+	if(is.numeric(i))
+		i = 1:nrow(x@time) %in% i
+	if(is.numeric(j))
+		j = 1:nrow(x@time) %in% j
+
+	i = i & j
 
 	x@sp = x@sp[i]
 	x@time = x@time[i]
-	x@data = x@data[i, j, drop = FALSE]
+	x@data = x@data[i, k, drop = FALSE]
 	if (drop && length(unique(index(x@time))) == 1)
-		x = asSpatialDataFrame(x)
+		x = addAttrToGeom(x@sp, x@data, match.ID = FALSE)
 	x
 }
 setMethod("[", "STSDF", subs.STSDF)
